# setup ####
rm(list=ls()); # remove all objects from workspace
cat("\014") # clear console
Sys.setenv(TZ='Utc') ## R don't change Date/Times; Utc= don't switch data timezone you are in

library(stringr)
library(reshape2)
source('./RegressionOnPlot_2024-09-29_was.R')

# Import Data ####
data <- read.csv("../1_Input/resultphyschem.csv")

# Clean up data ####
# Replace retired names
data$CharacteristicName[data$CharacteristicName == 
  "Nutrient-nitrogen***retired***use TOTAL NITROGEN, MIXED FORMS with speciation AS N"] <- 
  "Total Nitrogen, mixed forms"

data$CharacteristicName[data$CharacteristicName == 
  "Inorganic nitrogen (nitrate and nitrite) ***retired***use Nitrate + Nitrite"] <-
     "Nitrate + Nitrite"

# Drop results that are "Not Reported" and export list as csv
notreport <- data[c(which(data$ResultDetectionConditionText == 
                            "Not Reported")) ,]

data <- data[!data$ResultDetectionConditionText == "Not Reported" ,]

if(length(notreport$OrganizationIdentifier > 0)){
  
  write.csv(notreport, 
            "../3_IntermediateOutput/NotReported_DroppedFromUpload.csv")
  
}

# Standardize Units
if(any(str_detect(data$ResultMeasure.MeasureUnitCode, "mg/L"))&
   any(str_detect(data$ResultMeasure.MeasureUnitCode, "ug/L"))){
  
  data$ResultMeasureValue[data$ResultMeasure.MeasureUnitCode == "mg/L"] <- 
    data$ResultMeasureValue[data$ResultMeasure.MeasureUnitCode == "mg/L"]*1000
  data$ResultMeasure.MeasureUnitCode[data$ResultMeasure.MeasureUnitCode == "mg/L"] <- "ug/L"
  
}

# change non-detect numeric values to zeros
data[data$ResultDetectionConditionText == 'Not Detected', 
     'ResultMeasureValue'] <- 0


# Restructure data ####
data1 <- data[, c('MonitoringLocationName', 'ActivityStartDate',
                  'CharacteristicName', 'ResultMeasureValue')]

colnames(data1) <- c('site', 'date', 'param', 'value')

wide <- dcast(data1, site + date ~ param, value.var = 'value', median)

# legend ####
butcher <- 'blue'
rose <- 'black'
still <- 'darkgreen'

legend <- data.frame(site = unique(wide$site),
                     pch = 1:12,
                     col = c(rep(butcher, 3),
                             rep(rose, 3),
                             rep(still, 4),
                             butcher, still))

wide <- merge(wide, legend, by = 'site')

# Nitrate versus TN ####
# range(wide$`Total Nitrogen, mixed forms`, na.rm = TRUE)
# range(wide$`Nitrate + Nitrite`, na.rm = TRUE)

# windows(500,500)
png(1000, 1000, res = 100, filename = '../4_FinalOutput/plots_regression/No3_vs_TN.png')
plot(x = wide$`Total Nitrogen, mixed forms`, 
     y = wide$`Nitrate + Nitrite`,
     xlab = 'Total Nitrogen (mg/L)', ylab = 'Nitrate-N (mg/L)',
     pch = wide$pch, col = wide$col, 
     xlim = c(0,1.1), ylim = c(0, 1.1),
     main = 'Nitrate-N versus Total Nitrogen')
abline(a = 0, b = 1)
legend('topleft', legend = legend$site, pch = legend$pch, col = legend$col)
dev.off()

# TSS vs Turbidity ####
# colnames(wide)
# range(wide$`Total suspended solids`, na.rm = TRUE)
# range(wide$`Turbidity`, na.rm = TRUE)

# windows(500,500)
png(1000, 1000, res = 100, filename = '../4_FinalOutput/plots_regression/Tss_vs_Turb_all.png')
plot(x = wide$`Total suspended solids`, 
     y = wide$`Turbidity`,
     xlab = 'TSS (mg/L)', ylab = 'Turbidity (NTU)',
     pch = wide$pch, col = wide$col, 
     # xlim = c(0,1.1), ylim = c(0, 1.1),
     main = 'Turbidity versus Total Suspended Solids')
legend('topleft', legend = legend$site, pch = legend$pch, col = legend$col)
RegressionOnPlot(x.values = wide$`Total suspended solids`, 
                 y.values = wide$`Turbidity`,
                 label.x.cord =  800, label.y.cord = 200)

dev.off()

# zoomed in
# windows(500,500)
png(1000, 1000, res = 100, filename = '../4_FinalOutput/plots_regression/Tss_vs_Turb_zoom.png')
plot(x = wide$`Total suspended solids`, 
     y = wide$`Turbidity`,
     xlab = 'TSS (mg/L)', ylab = 'Turbidity (NTU)',
     pch = wide$pch, col = wide$col, 
     xlim = c(0,200), ylim = c(0, 200),
     main = 'Turbidity versus Total Suspended Solids')
legend('topleft', legend = legend$site, pch = legend$pch, col = legend$col)
RegressionOnPlot(x.values = wide$`Total suspended solids`, 
                 y.values = wide$`Turbidity`,
                 label.x.cord =  150, label.y.cord = 50)
dev.off()

# TSS vs TP ####
# range(wide$`Total suspended solids`, na.rm = TRUE)
# range(wide$`Total Phosphorus, mixed forms`, na.rm = TRUE)

png(1000, 1000, res = 100, filename = '../4_FinalOutput/plots_regression/TP_vs_TSS.png')
plot(x = wide$`Total suspended solids`, 
     y = wide$`Total Phosphorus, mixed forms`,
     xlab = 'TSS (mg/L)', ylab = 'TP (mg/L)',
     pch = wide$pch, col = wide$col, 
     # xlim = c(0,200), ylim = c(0, 200),
     main = 'Total Phosphorus versus Total Suspended Solids')
legend('bottomright', legend = legend$site, pch = legend$pch, col = legend$col)
RegressionOnPlot(x.values = wide$`Total suspended solids`,
                 y.values = wide$`Total Phosphorus, mixed forms`,
                 label.x.cord =  200, label.y.cord = 1)
dev.off()

# TSS vs Flow (butcher only) ####
# colnames(wide)
wide.flow <- wide[!is.na(wide$Flow), ]
wide.flow <- wide.flow[wide.flow$col == 'blue',]
range(wide.flow$`Flow`, na.rm = TRUE)
range(wide.flow$`Total suspended solids`, na.rm = TRUE)
legend.butcher <- legend[legend$col == 'blue',]

png(1000, 1000, res = 100, filename = '../4_FinalOutput/plots_regression/TSS_vs_flow.png')
plot(x = wide.flow$`Flow`, 
     y = wide.flow$`Total suspended solids`,
     xlab = 'Flow (cfs)', ylab = 'TSS (mg/L)',
     pch = wide.flow$pch, col = wide.flow$col, 
     # xlim = c(0,200), ylim = c(0, 200),
     main = 'Total Suspended Solids versus Flow')
legend('topleft', legend = legend.butcher$site, 
       pch = legend.butcher$pch, col = legend.butcher$col)
RegressionOnPlot(x.values = wide.flow$`Flow`,
                 y.values = wide.flow$`Total suspended solids`,
                 label.x.cord =  10, label.y.cord = 300)
dev.off()



# End ####









